==> haskell-refinery-0.4.0.0-294-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-E3DObqFNjhoKds0vnHfQce
key:                  refinery-0.4.0.0-E3DObqFNjhoKds0vnHfQce
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  55b1cc2c868a5a629e217bbf31cba0ad
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-E3DObqFNjhoKds0vnHfQce
depends:
    base-4.17.2.1 exceptions-0.10.5 mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-refinery-0.4.0.0-295-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-IVA3B5wBcB2Fpfq7BmSy3k
key:                  refinery-0.4.0.0-IVA3B5wBcB2Fpfq7BmSy3k
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  3d0cfbcfb40f58a624cfc70fd1ecc5a4
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-IVA3B5wBcB2Fpfq7BmSy3k
depends:
    base-4.17.2.1 exceptions-0.10.5 mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
